@@ -5,95 +5,118 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Thư điện tử được cung cấp không khả dụng",
     "%s has published the calendar »%s«" : "%s vừa đăng tải thông tin vào lịch »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Một lỗi không mong đợi khi đang gửi thư điện tử. Vui lòng liên hệ quản trị viên của bạn",
+    "Successfully sent email to %1$s" : "Đã gửi email thành công đến %1$s",
     "Hello," : "Xin chào,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Chúng tôi muốn thông báo với bạn rằng %s vừa đăng tải thông tin vào lịch »%s«.",
     "Open »%s«" : "Mở »%s«",
     "Cheers!" : "Xin chúc mừng!",
     "Upcoming events" : "Các sự kiện sắp diễn ra",
+    "No more events today" : "Không có thêm sự kiện nào hôm nay",
+    "No upcoming events" : "Không có sự kiện sắp diễn ra ",
     "Calendar" : "Lịch",
+    "Appointments" : "Các lịch hẹn ",
+    "Schedule appointment \"%s\"" : "Lên lịch lịch hẹn \"%s\"",
+    "Schedule an appointment" : "Lên lịch một lịch hẹn",
+    "Prepare for %s" : "Chuản bị cho %s",
+    "Follow up for %s" : "Diễn tiến cho %s",
+    "Dear %s, please confirm your booking" : "%s thân ái, vui lòng xác nhận lịch đặt hẹn của bạn",
+    "Confirm" : "Xác nhận",
+    "Description:" : "Mô tả:",
+    "This confirmation link expires in %s hours." : "Liên kết xác nhận sẽ hết hạn trong %s giờ.",
+    "Date:" : "Ngày:",
+    "Where:" : "Địa điểm:",
     "A Calendar app for Nextcloud" : "Một ứng dụng Lịch nhắc nhở cho Hệ thống",
     "Previous day" : "Ngày trước",
     "Previous week" : "Tuần trước",
     "Previous month" : "Tháng trước",
     "Next day" : "Ngày hôm sau",
     "Next week" : "Tuần sau",
+    "Next year" : "Năm tiếp theo",
     "Next month" : "Tháng sau",
-    "+ New event" : "+ Sự kiện mới",
     "Today" : "Hôm nay",
     "Day" : "Ngày",
     "Week" : "Tuần",
     "Month" : "Tháng",
+    "Year" : "Năm",
     "List" : "Danh sách",
-    "Untitled calendar" : "Lịch không tiêu đề",
-    "Edit name" : "Sửa đổi tên",
-    "Saving name …" : "Đang lưu tên  …",
-    "Edit color" : "Sửa đổi màu",
-    "Saving color …" : "Đang sửa đổi màu  …",
-    "Copy private link" : "Sao chép liên kết riêng tư",
-    "Download" : "Tải về",
-    "Unshare from me" : "Gỡ chia sẻ khỏi tôi",
+    "Appointment link was copied to clipboard" : "Liên kết cuộc hẹn đã được sao chép vào bảng tạm",
+    "Appointment link could not be copied to clipboard" : "Liên kết cuộc hẹn không thể được sao chép vào bảng tạm",
+    "Preview" : "Xem trước",
+    "Copy link" : "Sao chép liên kết",
+    "Edit" : "Chỉnh sửa",
     "Delete" : "Xóa",
+    "Create new" : "Tạo mới",
     "An error occurred, unable to change visibility of the calendar." : "Một lỗi đã xảy ra, không thể thay đổi tính hiển thị của lịch.",
-    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
-    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
-    "Calendar link could not be copied to clipboard." : "Liên kết của lịch không thể sao chép vào bảng tạm.",
-    "An error occurred, unable to rename the calendar." : "Một lỗi đã xảy ra, không thể đổi tên của lịch.",
-    "An error occurred, unable to change the calendar's color." : "Một lỗi đã xảy ra, không thể thay đổi màu sắc của lịch.",
+    "Untitled calendar" : "Lịch không tiêu đề",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Đang gỡ chia sẻ của lịch trong {countdown} giây"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Đang xóa lịch trong {countdown} giây"],
-    "Share link" : "Liên kết chia sẽ",
-    "Publish calendar" : "Công khai lịch",
-    "Publishing calendar" : "Đang công khai lịch",
-    "Copy public link" : "Sao chép liên kết công khai",
-    "Send link to calendar via email" : "Gửi liên kết đến lịch thông qua thư điện tử",
-    "Enter one address" : "Điền vào môt địa chỉ",
-    "Sending email …" : "Đang gửi email ...",
+    "An error occurred, unable to create the calendar." : "Một lỗi đã xảy ra, không thẻ tạo lịch.",
+    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vui lòng nhập vào một liên kết khả dụng ( bắt đầu với http://, https://, webcal://, hoặc webcals://)",
+    "Calendars" : "Lịch",
+    "Add new" : "Thêm mới",
+    "New calendar" : "Lịch mới",
+    "Name for new calendar" : "Tên cho lịch mới",
+    "Creating calendar …" : "Đang tạo lịch  …",
+    "New calendar with task list" : "Lịch mới với danh sách nhiệm vụ",
+    "New subscription from link (read-only)" : "Đăng kí theo dõi mới từ liên kết (Chỉ-đọc)",
+    "Creating subscription …" : "Đang tạo đăng kí theo dõi mới  …",
+    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
+    "Calendar link could not be copied to clipboard." : "Liên kết của lịch không thể sao chép vào bảng tạm.",
     "Copy subscription link" : "Sao chép liên kết theo dõi ",
     "Copying link …" : "Sao chép liên kết  ...",
     "Copied link" : "Liên kết đã được sao chép",
     "Could not copy link" : "Không thể sao chép liên kết",
+    "Export" : "Xuất ra",
+    "Unknown calendar" : "Lịch không rõ nguồn",
+    "Could not load deleted calendars and objects" : "Không thể hiển thị lịch hoặc các đối tượng đã xoá",
+    "Could not restore calendar or event" : "Không thể khôi phục lịch hoặc sự kiện",
+    "Do you really want to empty the trash bin?" : "Bạn có chắc là muốn dọn sạch thùng rác hay không?",
+    "Empty trash bin" : "Dọn thùng rác",
+    "Trash bin" : "Thùng rác",
+    "Name" : "Tên",
+    "Deleted" : "Đã xoá",
+    "Restore" : "Khôi phục",
+    "Delete permanently" : "Xoá vĩnh viễn",
+    "Could not update calendar order." : "Không thể cập nhật thứ tự của lịch",
+    "Deck" : "Kế hoạch",
+    "Hidden" : "Ẩn",
+    "Internal link" : "Liên kết nội bộ",
+    "An error occurred, unable to publish calendar." : "Có lỗi đã xảy ra, không thể công khai lịch.",
+    "An error occurred, unable to send email." : "Một lỗi đã xảy ra, không thể gửi email.",
+    "Embed code copied to clipboard." : "Mã nhúng đã được sao chép vào bảng tạm.",
+    "Embed code could not be copied to clipboard." : "Mã nhúng không thể được sao chép vào bảng tạm.",
+    "Unpublishing calendar failed" : "Gỡ công khai cho lịch thất bại",
+    "Share link" : "Liên kết chia sẽ",
+    "Copy public link" : "Sao chép liên kết công khai",
+    "Send link to calendar via email" : "Gửi liên kết đến lịch thông qua thư điện tử",
+    "Enter one address" : "Điền vào môt địa chỉ",
+    "Sending email …" : "Đang gửi email ...",
     "Copy embedding code" : "Đang sao chép mã nhúng",
     "Copying code …" : "Đang sao chép mã  ...",
     "Copied code" : "Đã sao chép dòng lệnh",
     "Could not copy code" : "Không thể sao chép dòng lệnh",
     "Delete share link" : "Xóa liên kết chia sẻ",
     "Deleting share link …" : "Đang xóa liên kết chia sẻ  ...",
-    "An error occurred, unable to publish calendar." : "Có lỗi đã xảy ra, không thể công khai lịch.",
-    "An error occurred, unable to send email." : "Một lỗi đã xảy ra, không thể gửi email.",
-    "Embed code copied to clipboard." : "Mã nhúng đã được sao chép vào bảng tạm.",
-    "Embed code could not be copied to clipboard." : "Mã nhúng không thể được sao chép vào bảng tạm.",
-    "Unpublishing calendar failed" : "Gỡ công khai cho lịch thất bại",
-    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
-    "No users or groups" : "Không có người dùng hay nhóm",
+    "An error occurred, unable to change the permission of the share." : "Một lỗi đã diễn ra, không thể thay đổi quyền hạn chia sẻ",
     "can edit" : "có thể chỉnh sửa",
     "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
-    "An error occurred, unable to change the unshare the calendar." : "Một lỗi đã xảy ra, không thể thay đổi thuộc tính chia sẻ của lịch ",
-    "An error occurred, unable to change the permission of the share." : "Một lỗi đã diễn ra, không thể thay đổi quyền hạn chia sẻ",
-    "+ New calendar" : "+ Lịch mới",
-    "New calendar" : "Lịch mới",
-    "Creating calendar …" : "Đang tạo lịch  …",
-    "New calendar with task list" : "Lịch mới với danh sách nhiệm vụ",
-    "New subscription from link (read-only)" : "Đăng kí theo dõi mới từ liên kết (Chỉ-đọc)",
-    "Creating subscription …" : "Đang tạo đăng kí theo dõi mới  …",
-    "An error occurred, unable to create the calendar." : "Một lỗi đã xảy ra, không thẻ tạo lịch.",
-    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vui lòng nhập vào một liên kết khả dụng ( bắt đầu với http://, https://, webcal://, hoặc webcals://)",
-    "Could not update calendar order." : "Không thể cập nhật thứ tự của lịch",
+    "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
+    "No users or groups" : "Không có người dùng hay nhóm",
+    "Unshare from me" : "Gỡ chia sẻ khỏi tôi",
+    "Save" : "Lưu",
     "Import calendars" : "Nhập lịch",
     "Please select a calendar to import into …" : "Vui lòng chọn một lịch để nhập vào  …",
     "Filename" : "Tên tập tin",
     "Calendar to import into" : "Lịch để nhập vào",
     "Cancel" : "Hủy",
     "_Import calendar_::_Import calendars_" : ["Nhập lịch"],
-    "{filename} is an unsupported file-type" : "{filename}  là một kiểu loại tệp không được hỗ trợ",
     "{filename} could not be parsed" : "{filename} không thể được phân tách",
     "No valid files found, aborting import" : "Không có tệp khả dụng được tìm thấy, đang hủy quá trình nhập",
+    "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n sự kiện đã được nhập vào thành công"],
     "Import partially failed. Imported {accepted} out of {total}." : "Quá trình nhập thất bại 1 phần. Đã nhập {accepted} trong tổng {total}.",
-    "_Successfully imported %n event_::_Successfully imported %n events._" : [" %n sự kiện đã được nhập thành công"],
     "Automatic" : "Tự động",
     "Automatic ({detected})" : " ({detected}) tự động",
     "New setting was not saved successfully." : "Thiết lập mới không được lưu thành công",
-    "Shortcut overview" : "Bản xem trước của lối tắt",
-    "or" : "hoặc",
     "Navigation" : "Điều hướng",
     "Previous period" : "Kỳ trước",
     "Next period" : "Kỳ tiếp theo",
@@ -101,21 +124,77 @@ OC.L10N.register(
     "Day view" : "Xem theo ngày",
     "Week view" : "Xem theo tuần",
     "Month view" : "Xem theo tháng",
+    "List view" : "Xem theo danh sách",
     "Actions" : "Hành động",
     "Create event" : "Tạo sự kiện mới",
     "Show shortcuts" : "Hiển thị các phím tắt",
+    "Editor" : "Trình biên tập",
+    "Close editor" : "Đóng trình biên tập",
+    "Save edited event" : "Lưu lại sự kiện được chỉnh sửa",
+    "Delete edited event" : "Xoá sự kiện được chỉnh sửa",
+    "Shortcut overview" : "Bản xem trước của lối tắt",
+    "or" : "hoặc",
+    "No reminder" : "Không có nhắc hẹn",
+    "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
+    "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
     "Enable birthday calendar" : "Bật lịch sinh nhật",
     "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
     "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
-    "Limit visible events per view" : "Hạn chế các sự kiện có thể thấy trên mỗi lượt xem",
     "Show weekends" : "Cho thấy ngày cuối tuần",
     "Show week numbers" : "Hiển thị số tuần",
+    "Time increments" : "Mức tăng thời gian",
+    "Default reminder" : "Nhác hẹn mặc định",
     "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
     "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
+    "Personal availability settings" : "Thiết lập lịch trống cá nhân",
     "Show keyboard shortcuts" : "Hiển thị các phím tắt",
-    "Settings & import" : "Thiết lập & Nhập vào",
-    "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
-    "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} phút"],
+    "0 minutes" : "0 phút",
+    "_{duration} hour_::_{duration} hours_" : ["{duration} giờ"],
+    "_{duration} day_::_{duration} days_" : ["{duration} ngày"],
+    "_{duration} week_::_{duration} weeks_" : ["{duration} tuần"],
+    "_{duration} month_::_{duration} months_" : ["{duration} tháng"],
+    "_{duration} year_::_{duration} years_" : ["{duration} năm"],
+    "To configure appointments, add your email address in personal settings." : "Để cấu hình lịch hẹn, thêm vào địa chỉ email trong thiết lập cá nhân.",
+    "Public – shown on the profile page" : "Công cộng - Được hiển thị công khai trên trang thông tin cá nhân",
+    "Private – only accessible via secret link" : "Riêng tư - Chỉ có thể truy cập thông qua liên kết bí mật",
+    "Update" : "Cập nhật",
+    "Location" : "Vị trí",
+    "Description" : "Mô tả",
+    "Visibility" : "Hiển thị",
+    "Duration" : "Khoảng thời gian",
+    "Increments" : "Tăng thêm",
+    "Additional calendars to check for conflicts" : "Lịch phụ để kiểm tra trùng lặp",
+    "Pick time ranges where appointments are allowed" : "Chọn khoản thời gian khả dĩ cho các cuộc hẹn",
+    "to" : "đến",
+    "Delete slot" : "Xoá suất",
+    "No times set" : "Thời gian không được thiết lập",
+    "Add" : "Thêm",
+    "Monday" : "Thứ 2",
+    "Tuesday" : "Thứ ba",
+    "Wednesday" : "Thứ tư",
+    "Thursday" : "Thứ năm",
+    "Friday" : "Thứ sáu",
+    "Saturday" : "Thứ bảy",
+    "Sunday" : "Chủ Nhật",
+    "Add time before and after the event" : "Thêm thời gian trước và sau sự kiện",
+    "Before the event" : "Trước sự kiện",
+    "After the event" : "Sau sự kiện",
+    "Planning restrictions" : "Các loại trừ cho kế hoạch",
+    "Minimum time before next available slot" : "Thời gian tối thiểu trước một suất mở",
+    "Max slots per day" : "Số suất tối đa trong ngày",
+    "Limit how far in the future appointments can be booked" : "Giới hạn khoảng thời gian bao xa trong tương lai mà lịch hẹn có thể được đặt",
+    "Please confirm your reservation" : "Vui lòng xác nhận đặt chỗ của bạn",
+    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Chúng tôi đã gửi bạn một email với đầy đủ chi tiết. Vui lòng xác nhận lịch hẹn của bạn bằng liên kết trong email. Bây giờ bạn đã có thể đóng trang này.",
+    "Your name" : "Tên của bạn",
+    "Your email address" : "Địa chỉ email của bạn",
+    "Please share anything that will help prepare for our meeting" : "Vui lòng chia sẻ bất cứ gì có thể giúp cho việc chuẩn bị cho cuộc hẹn  ",
+    "Could not book the appointment. Please try again later or contact the organizer." : "Không thể đặt lịch hẹn. Vui lòng thử lại sau hoặc liên hệ với người tổ chức.",
+    "Back" : "Trở lại",
+    "Select conversation" : "Chọn cuộc trò chuyện",
+    "on" : "trên",
+    "at" : "vào lúc",
+    "Reminder" : "Lịch nhắc hẹn",
     "before at" : "trước lúc",
     "Notification" : "Thông báo",
     "Email" : "Thư điện tử",
@@ -126,72 +205,97 @@ OC.L10N.register(
     "Edit time" : "Chỉnh sửa thời gian",
     "Save time" : "Lưu thời gian",
     "Remove reminder" : "Gỡ bỏ lịch nhắc hẹn",
-    "on" : "trên",
-    "at" : "vào lúc",
     "+ Add reminder" : "+ Thêm lịch nhắc hẹn",
-    "_second_::_seconds_" : ["giây"],
-    "_minute_::_minutes_" : ["phút"],
-    "_hour_::_hours_" : ["giờ"],
-    "_day_::_days_" : ["ngày"],
-    "_week_::_weeks_" : ["tuần"],
-    "Availability of attendees, resources and rooms" : "Tình trạng tham gia của người dự, nguồn lực và phòng ",
+    "Add reminder" : "Thêm vào nhắc hẹn",
+    "seconds" : "giây",
+    "minutes" : "phút",
+    "hours" : "giờ",
+    "days" : "ngày",
+    "weeks" : "tuần",
+    "Choose a file to add as attachment" : "Chọn một tệp để thêm dưới dạng tệp đính kèm",
+    "Choose a file to share as a link" : "Chọn một tệp để chia sẻ dưới dạng liên kết",
+    "Proceed" : "Tiến hành",
+    "Delete file" : "Xóa tệp",
+    "Suggested" : "Được đề xuất",
+    "Available" : "khả dụng",
+    "Invitation accepted" : "Lời mời đã được chấp nhận",
+    "Accepted {organizerName}'s invitation" : "Đã chấp nhận lời mời của {organizerName}",
+    "Not available" : "Không khả dụng",
+    "Invitation declined" : "Lời mời đã bị từ chối",
+    "Declined {organizerName}'s invitation" : "Đã từ chối lời mời của {organizerName}",
+    "Checking availability" : "Đang kiểm tra lịch trống",
+    "{organizer} (organizer)" : "{organizer} (người tổ chức)",
     "Free" : "Rãnh",
     "Busy (tentative)" : "Bận (có khả năng thay đổi)",
     "Busy" : "Bận",
     "Out of office" : "Không ở văn phòng",
     "Unknown" : "Không xác định",
-    "Create Talk room for this event" : "Tạo một phòng trò chuyện cho sự kiện này",
-    "Show busy times" : "Cho thấy các thời gian bận",
+    "Availability of attendees, resources and rooms" : "Tình trạng tham gia của người dự, nguồn lực và phòng ",
+    "Done" : "Hoàn thành",
+    "Room name" : "Tên phòng",
+    "Accept" : "Đồng ý",
+    "Decline" : "Từ chối",
+    "Tentative" : "Chưa chắc chắn",
     "No attendees yet" : "Chưa có giờ tham gia",
     "Successfully appended link to talk room to description." : "Liên kết đã được thêm thành công vào mô tả trong phòng trò chuyện ",
     "Error creating Talk room" : "Có lõi xảy ra khi tạo phòng Trò chuyện",
+    "Attendees" : "Người tham gia",
+    "Remove group" : "Xóa nhóm",
+    "Remove attendee" : "Gỡ bỏ người tham gia",
     "Chairperson" : "Chủ tịch",
     "Required participant" : "Người tham gia được yêu cầu",
     "Optional participant" : "Người tham gia không bắt buộc",
     "Non-participant" : "Người không tham gia",
-    "Remove attendee" : "Gỡ bỏ người tham gia",
     "No match found" : "Không có khớp lệnh nào được tìm thấy",
     "(organizer)" : "(organizer)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Để gửi lời mời và tiếp nhận các phản hồi, [linkopen] thêm địa chỉ email riêng của bạn trong phần cài đặt cá nhân[linkclose].",
     "Remove color" : "Gỡ màu",
     "Event title" : "Tiêu đề sự kiện",
+    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Không thể điều chỉnh thiết lập cả-ngày cho các sự kiện là một phần của sự kiện-lặp lại.",
+    "From" : "Từ",
+    "To" : "Tới",
     "All day" : "Cả ngày",
-    "from {startDate}" : "từ {startDate}",
-    "from {startDate} at {startTime}" : "từ {startDate} vào lúc {startTime}",
-    "to {endDate}" : "đến  {endDate}",
-    "to {endDate} at {endTime}" : "đến {endDate} vào lúc {endTime}",
     "Repeat" : "Lặp lại",
-    "Save" : "Lưu",
-    "End repeat" : "Kết thúc lập lại",
-    "Select to end repeat" : "Chọn thời gian kết thúc lặp lại",
+    "_time_::_times_" : ["lần"],
     "never" : "không thay đổi",
     "on date" : "vào ngày",
     "after" : "sau khi",
-    "_time_::_times_" : ["lần"],
+    "End repeat" : "Kết thúc lập lại",
+    "Select to end repeat" : "Chọn thời gian kết thúc lặp lại",
+    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Sự kiện này là loại trừ trong một bộ sự kiện-lặp lại. Bạn không thể thêm bất cứ qui tắc-lặp lại nào vào nó. ",
     "first" : "đầu tiên",
-    "third" : "vị trí thứ ba",
-    "fourth" : "vị trí thứ tư",
-    "fifth" : "vị trí thứ năm",
-    "second to last" : "kế cuối",
-    "last" : "cuối cùng",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "các thay đổi đến luật lệ định kỳ này sẽ chỉ áp dụng cho định kỳ này và các định kỳ tương lai của nó ",
     "Repeat every" : "Lặp lại mỗi",
     "By day of the month" : "Vào ngày của tháng",
     "On the" : "Trên",
+    "_day_::_days_" : ["ngày"],
+    "_week_::_weeks_" : ["tuần"],
     "_month_::_months_" : ["tháng"],
     "_year_::_years_" : ["năm"],
-    "Monday" : "Thứ 2",
     "weekday" : "ngày làm việc",
     "weekend day" : "ngày cuối tuần",
+    "Does not repeat" : "Không lặp lại",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Định nghĩa về định kỳ của sự kiện này không hoàn toàn được hỗ trợ bởi vWorkspace. Nếu bạn sửa các lựa chọn định kỳ này, một vài định kỳ có thể sẽ bị mất ",
-    "More" : "Thêm",
-    "Update" : "Cập nhật",
-    "Update this occurrence" : "Cập nhập định kỳ này",
+    "No rooms or resources yet" : "Chưa có phòng hoặc nguồn lực",
+    "Suggestions" : "Các đề suất",
+    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} chỗ ngồi"],
+    "Add resource" : "Thêm nguồn lực",
+    "Has a projector" : "Có máy chiếu",
+    "Has a whiteboard" : "Có bảng đen ",
+    "Wheelchair accessible" : "Có lối đi cho người khuyết tật",
+    "Remove resource" : "Gỡ bỏ nguồn lực",
+    "Search for resources or rooms" : "Tìm kiếm cho nguồn lực hoặc phòng trống",
+    "available" : "khả dụng",
+    "unavailable" : "không khả dụng",
+    "Projector" : "Máy chiếu",
+    "Whiteboard" : "Bảng viết",
+    "Room type" : "Loại phòng",
+    "Any" : "Bất cứ",
+    "Minimum seating capacity" : "Số ghế ngồi tối thiểu",
     "Update this and all future" : "Cập nhập định kỳ này và cho toàn bộ tương lai",
+    "Update this occurrence" : "Cập nhập định kỳ này",
     "Public calendar does not exist" : "Lịch công khai không tồn tại",
     "Maybe the share was deleted or has expired?" : "Có lẽ chia sẽ đã bị xóa hoặc hết hạn ? ",
-    "Pick a time" : "Chọn thời gian",
-    "Pick a date" : "Chọn ngày",
     "from {formattedDate}" : "từ {formattedDate}",
     "to {formattedDate}" : "đến {formattedDate}",
     "on {formattedDate}" : "vào {formattedDate}",
@@ -201,24 +305,39 @@ OC.L10N.register(
     "{formattedDate} at {formattedTime}" : "{formattedDate} vào lúc {formattedTime}",
     "Please enter a valid date" : "Vui lòng điền vào 1 ngày khả dụng",
     "Please enter a valid date and time" : "Vui lòng điền vào 1 ngày và thời gian khả dụng",
+    "Please select a time zone:" : "Vui lòng chọn múi thời gian:",
+    "Pick a time" : "Chọn thời gian",
+    "Pick a date" : "Chọn ngày",
+    "Type to search time zone" : "Nhập để kiếm cho múi thời gian",
     "Global" : "Chung",
+    "Subscribed" : "Đã đăng ký",
+    "Subscribe" : "Theo dõi",
+    "Select slot" : "Chọn suất",
+    "No slots available" : "Không có suất trống",
+    "The slot for your appointment has been confirmed" : "Suất cho cuộc hẹn của bạn đã được xác nhận",
+    "Appointment Details:" : "Chi tiết cuộc hẹn:",
+    "Time:" : "Thời gian:",
+    "Booked for:" : "Đã đặt cho:",
+    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Cảm ơn. Lịch hẹn của bạn từ {startDate} đến {endDate} đã được xác nhận.",
+    "Book another appointment:" : "Đặt một cuộc hẹn khác:",
+    "See all available slots" : "Hiển thị toàn bộ các suất trống ",
+    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Suất cho cuộc hẹn của bạn từ {startDate} đến {endDate} hiện không còn trống.",
+    "Please book a different slot:" : "Vui lòng đặt một suất khác:",
+    "Book an appointment with {name}" : "Đặt một cuộc hẹn với {name}",
+    "No public appointments found for {name}" : "Không cuộc hẹn công khai nào cho {name} được tìm thấy",
     "Personal" : "Cá nhân",
-    "No more events today" : "Không có thêm sự kiện nào hôm nay",
-    "No upcoming events" : "Không có sự kiện sắp diễn ra ",
-    "Create a new event" : "Tạo một sự kiện mới",
-    "[Today]" : "[Hôm nay]",
-    "[Tomorrow]" : "[Ngày mai]",
-    "[Yesterday]" : "[Hôm qua]",
-    "[Last] dddd" : "[Trước] dddd",
+    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Chức năng tự động phát hiện múi giờ đã xác định múi giờ của bạn là UTC. \nRất có khả năng đây là kết quả lấy từ các tuỳ chỉnh bảo mật trong trình duyệt của bạn.\nVui lòng chuyển đổi thủ công múi của giờ của bạn trong phần thiết lập của Lịch",
+    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Không tìm thấy múi giờ ({timezoneId}) được cấu hình của bạn. Thiết lập múi giờ sẽ được trở về lại UTC. Vui lòng thay đổi múi giờ của bạn trong phần cài đặt và hãy báo cáo sự cố này. ",
     "Event does not exist" : "Sự kiện không tồn tại",
     "Delete this occurrence" : "Xóa định kỳ này",
     "Delete this and all future" : "Xóa địnhy kỳ này và tất cả tương lai của nó",
     "Details" : "Chi tiết",
-    "Attendees" : "Người tham gia",
+    "Invite" : "Mời",
+    "Resources" : "Các nguồn lực",
+    "Untitled event" : "Sự kiện không tiêu đề",
     "Close" : "Đóng",
-    "Show more details" : "Cho thấy thêm chi tiết",
     "Subscribe to {name}" : "Dõi theo {name}",
-    "Download {name}" : "Tải xuống {name}",
+    "Export {name}" : "Xuất dữ liệu bảng {name}",
     "Anniversary" : "Ngày kỷ niệm",
     "Appointment" : "Cuộc hẹn",
     "Business" : "Doanh nghiệp",
@@ -246,7 +365,6 @@ OC.L10N.register(
     "on {time}" : "vào  {time}",
     "on {time} ({timezoneId})" : "vào {time} ({timezoneId})",
     "Week {number} of {year}" : "Tuần thứ {number} của năm {year}",
-    "Does not repeat" : "Không lặp lại",
     "Daily" : "Hằng ngày",
     "Weekly" : "Hằng tuần",
     "Monthly" : "Hằng tháng",
@@ -258,13 +376,18 @@ OC.L10N.register(
     "_on {weekday}_::_on {weekdays}_" : ["vào  {weekdays}"],
     "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["vào các ngày {dayOfMonthList}"],
     "on the {ordinalNumber} {byDaySet}" : "vào {ordinalNumber} {byDaySet}",
-    "in {monthNames}" : "trong {monthNames}",
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "trong {monthNames} trên {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "cho đến {untilDate}",
     "_%n time_::_%n times_" : ["%n lần"],
-    "Untitled event" : "Sự kiện không tiêu đề",
+    "second" : "Thứ hai",
+    "third" : "vị trí thứ ba",
+    "fourth" : "vị trí thứ tư",
+    "fifth" : "vị trí thứ năm",
+    "second to last" : "kế cuối",
+    "last" : "cuối cùng",
     "Untitled task" : "Nhiệm vụ không tiêu đề",
     "Please ask your administrator to enable the Tasks App." : "Vui lòng hỏi quản trị viên của bạn để bật ứng dụng Nhiệm Vụ",
+    "W" : "T",
     "%n more" : "thêm %n",
     "No events to display" : "không có sự kiện để hiển thị",
     "_+%n more_::_+%n more_" : ["+ thêm %n "],
@@ -272,115 +395,32 @@ OC.L10N.register(
     "Create a new event or change the visible time-range" : "Tạo sự kiện mới hoặc thay đổi khung thời gian hiển thị",
     "It might have been deleted, or there was a typo in a link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
     "It might have been deleted, or there was a typo in the link" : "Đường dẫn có thể đã bị xóa, hoặc đã có lỗi đánh máy trong liên kết",
-    "When shared show" : "Khi được chia sẻ thì cho thấy",
-    "When shared show full event" : "Khi được chia sẻ thì cho thấy đầy đủ sự kiện",
-    "When shared show only busy" : "Khi được chia sẻ thì chỉ cho thấy đang bận",
+    "Meeting room" : "Phòng họp",
+    "Lecture hall" : "Giảng đường",
+    "Seminar room" : "Phòng hội nghị",
+    "Other" : "Khác",
+    "When shared show" : "Khi được chia sẻ thì hiển thị",
+    "When shared show full event" : "Khi được chia sẻ thì hiển thị đầy đủ sự kiện",
+    "When shared show only busy" : "Khi được chia sẻ thì chỉ hiển thị đang bận",
     "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
     "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ",
-    "Location" : "Vị trí",
     "Add a location" : "Thêm vào một địa điểm",
-    "Description" : "Mô tả",
-    "Add a description" : "Thêm vào một mô tả",
     "Status" : "Trạng thái",
     "Confirmed" : "Đã xác nhận",
-    "Tentative" : "Chưa chắc chắn",
     "Canceled" : "Đã bị hủy",
-    "Confirmation about the overall status of the event." : "Sự xác nhận về tình trạng tổng thể của sự kiện.",
-    "Show as" : "Cho thấy với",
-    "Take this event into account when calculating free-busy information." : "Lưu ý sự kiện này vào tài khoản khi tính toán về thông tin bận-rãnh",
+    "Confirmation about the overall status of the event." : "Xác nhận về tình trạng tổng thể của sự kiện.",
+    "Show as" : "Hiển thị như",
+    "Take this event into account when calculating free-busy information." : "Lưu ý đến sự kiện này khi tính toán về thông tin bận-rãnh",
     "Categories" : "Các hạng mục",
     "Categories help you to structure and organize your events." : "Các hạng mục này giúp bạn lên sườn và sắp xếp các sự kiện của bạn",
     "Search or add categories" : "Tìm kiếm và thêm vào các hạng mục",
     "Add this as a new category" : "Thêm mục này như là hạng mục mới",
     "Custom color" : "Tùy chỉnh màu",
     "Special color of this event. Overrides the calendar-color." : "Dùng màu đặc biệt cho sự kiện này. Ghi đè lên màu hiện hành",
-    "Chat room for event" : "Phòng trò chuyện cho sự kiện",
+    "Error while sharing file" : "Lỗi khi chia sẻ tệp",
+    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
     "Imported {filename}" : " {filename} đã được nhập",
-    "Meditation" : "Suy nghĩ",
-    "Relaxing" : "Thư giãn",
-    "Relax" : "Thư giãn",
-    "Presentation" : "Buổi thuyết trình",
-    "Present" : "Trình bày",
-    "Camping" : "Cắm trại",
-    "Camp" : "Cắm trại",
-    "Movie" : "Phim ảnh",
-    "Cinema" : "Rạp chiếu phim",
-    "Graduation" : "Lễ tốt nghiệp",
-    "Brainstorm" : "Động não",
-    "Baseball" : "Bóng chày",
-    "Meet" : "Gặp gỡ",
-    "Planning" : "Lên kế hoạch",
-    "Pointing" : "Đánh dấu",
-    "Retrospective" : "Nhìn nhận lại",
-    "Review" : "Đánh giá",
-    "Office" : "Văn phòng",
-    "Contributor week" : "Tuần lễ đóng góp",
-    "Mail" : "Thư điện tử",
-    "Soccer" : "Đá banh",
-    "Football" : "Bóng bầu dục",
-    "Gaming" : "Chơi game",
-    "Drive" : "Lái xe",
-    "Bicycle" : "Xep đạp",
-    "Cycle" : "Đi xe đạp",
-    "Biking" : "Đạp xe",
-    "Podcast" : "Podcast",
-    "Basketball" : "Bóng rổ",
-    "Fishing" : "Câu cá",
-    "Hiking" : "Leo núi",
-    "Hike" : "Leo",
-    "Art" : "Nghệ thuật",
-    "Exhibition" : "Triễn lãm",
-    "Museum" : "Nhà bảo tàng",
-    "Pilates" : "Thể dục kết hợp cường độ thấp",
-    "Park" : "Công viên",
-    "Studying" : "Học bài",
-    "Doctor" : "Bác sĩ",
-    "Health" : "Sức khỏe",
-    "Dentist" : "Nha sĩ",
-    "Interview" : "Phỏng vấn",
-    "Training" : "Luyện tập",
-    "Practice" : "Tập luyện",
-    "Sports" : "Các môn thể thao",
-    "Exercise" : "Tập thể dục",
-    "Work out" : "Tập thể dục",
-    "Working out" : "Tập thể dục",
-    "Gym" : "Gym",
-    "Barber" : "Thợ cắt tóc",
-    "Haircut" : "Cắt tóc",
-    "Exam" : "Thi",
-    "Working" : "Làm việc",
-    "New Years Eve" : "Đêm giao thừa",
-    "NYE" : "NYE",
-    "Fireworks" : "Pháo hoa",
-    "Running" : "Chạy bộ",
-    "Go for a run" : "Đi chạy bộ",
-    "Marathon" : "Chạy marathon",
-    "Video-conference" : "Hội nghị video",
-    "Conference-call" : "Hội nghị qua điện thoại",
-    "Video-call" : "Cuộc gọi video",
-    "Video-chat" : "Trò chuyện video",
-    "Video-meeting" : "Họp qua video",
-    "Call" : "Cuộc gọi",
-    "Calling" : "Đang gọi",
-    "Christmas" : "Giáng sinh",
-    "Conference" : "Họp",
-    "Pizza" : "Pizza",
-    "Travelling" : "Đi du lịch",
-    "Journey" : "Cuộc phiêu lưu",
-    "Collaborate" : "Hợp tác",
-    "Pair" : "Kết đôi ",
-    "Lecture" : "Bài giảng",
-    "Seminar" : "Hội thảo",
-    "Photograph" : "Bức ảnh",
-    "Party" : "Tiệc tùng",
-    "Celebration" : "Lễ kỉ niệm",
-    "Celebrate" : "Ăn mừng",
-    "Shopping" : "Đi mua sắm",
-    "Skate" : "Đi trượt ván",
-    "Skateboard" : "Ván trượt",
-    "Wine tasting" : "Thử rựu",
-    "Golf" : "Đánh gôn",
-    "Dinner" : "Dùng bữa tối",
-    "Lunch" : "Ăn trưa"
+    "Appointment not found" : "Không tìm thấy cuộc hẹn",
+    "User not found" : "Không tìm thấy người dùng"
 },
 "nplurals=1; plural=0;");
